==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/representations/ConstantObject.c <==
// public abstract class soot.jimple.toolkits.pointer.representations.ConstantObject

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class c25e2865de62d71a soot_jimple_toolkits_pointer_representations_AbstractObject
// @dep_class eaf7ad7a888244a0 soot_jimple_toolkits_pointer_representations_ConstantObject

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_jimple_toolkits_pointer_representations_AbstractObject
// @dep_header soot_jimple_toolkits_pointer_representations_ConstantObject

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/jimple/toolkits/pointer/representations/AbstractObject.h"
#include "soot/jimple/toolkits/pointer/representations/ConstantObject.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_representations_ConstantObject, _init$52f4ad9f2989aeee);

void
_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *this)
{
	struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(33);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String shortString()
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$shortString$fc1f709a9c723fa1[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$shortString$fc1f709a9c723fa1[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$shortString$fc1f709a9c723fa1 = {
	.name=			"shortString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$shortString$fc1f709a9c723fa1,
	.signature_hash=	_JC_JLONG(0xfc1f709a9c723fa1),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$shortString$fc1f709a9c723fa1,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable, soot_jimple_toolkits_pointer_representations_ConstantObject.shortString$fc1f709a9c723fa1) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$shortString$fc1f709a9c723fa1
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_representations_ConstantObject, shortString$fc1f709a9c723fa1);

_jc_java_lang_String$object *
_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$shortString$fc1f709a9c723fa1(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *this)
{
	struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(39);				// 0
	return _JC_STRING(env, "shortstring");
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable, soot_jimple_toolkits_pointer_representations_ConstantObject.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_representations_ConstantObject, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *this)
{
	struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(35);				// 0
	return _JC_STRING(env, "constantobject");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$methods[] = {
	&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$shortString$fc1f709a9c723fa1,
	&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$interfaces[] = {
	&_jc_soot_jimple_toolkits_pointer_representations_AbstractObject$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_26[] = {
	&_jc_soot_jimple_toolkits_pointer_representations_AbstractObject$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_32[] = {
	&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[26]=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_26,
	[32]=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_32,
	[113]=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/jimple/toolkits/pointer/representations/AbstractObject",	_JC_JLONG(0xc25e2865de62d71a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type = {
    .type= {
	.name=			"soot/jimple/toolkits/pointer/representations/ConstantObject",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$interfaces) / sizeof(*_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$interfaces),
	.interfaces=		_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xeaf7ad7a888244a0),
		.source_file=		"ConstantObject.java",
		.instance_size=		sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs) + sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$methods) / sizeof(*_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$methods),
		.methods=		_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$methods,
		.instanceof_hash_table=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_depends) / sizeof(*_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_depends),
		.class_depends=		_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_toolkits_pointer_representations_ConstantObject= {
	    .shortString$fc1f709a9c723fa1=
		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$shortString$fc1f709a9c723fa1,
	    .toString$7ea43b33b80a3070=
		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/jimple/toolkits/pointer/representations/ConstantObject.c <==
// public abstract class soot.jimple.toolkits.pointer.representations.ConstantObject

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class c25e2865de62d71a soot_jimple_toolkits_pointer_representations_AbstractObject
// @dep_class eaf7ad7a888244a0 soot_jimple_toolkits_pointer_representations_ConstantObject

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_jimple_toolkits_pointer_representations_AbstractObject
// @dep_header soot_jimple_toolkits_pointer_representations_ConstantObject

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/jimple/toolkits/pointer/representations/AbstractObject.h"
#include "soot/jimple/toolkits/pointer/representations/ConstantObject.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_representations_ConstantObject, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *this)
{
	struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(33);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String shortString()
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$shortString$fc1f709a9c723fa1[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$shortString$fc1f709a9c723fa1[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$shortString$fc1f709a9c723fa1 = {
	.name=			"shortString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$shortString$fc1f709a9c723fa1,
	.signature_hash=	_JC_JLONG(0xfc1f709a9c723fa1),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$shortString$fc1f709a9c723fa1,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable, soot_jimple_toolkits_pointer_representations_ConstantObject.shortString$fc1f709a9c723fa1) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$shortString$fc1f709a9c723fa1
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_representations_ConstantObject, shortString$fc1f709a9c723fa1);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$shortString$fc1f709a9c723fa1(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *this)
{
	struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(39);				// 0
	return _JC_STRING(env, "shortstring");
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable, soot_jimple_toolkits_pointer_representations_ConstantObject.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_representations_ConstantObject, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *this)
{
	struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(35);				// 0
	return _JC_STRING(env, "constantobject");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$methods[] = {
	&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$shortString$fc1f709a9c723fa1,
	&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$interfaces[] = {
	&_jc_soot_jimple_toolkits_pointer_representations_AbstractObject$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_26[] = {
	&_jc_soot_jimple_toolkits_pointer_representations_AbstractObject$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_32[] = {
	&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[26]=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_26,
	[32]=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_32,
	[101]=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/jimple/toolkits/pointer/representations/AbstractObject",	_JC_JLONG(0xc25e2865de62d71a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type = {
    .type= {
	.name=			"soot/jimple/toolkits/pointer/representations/ConstantObject",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$interfaces) / sizeof(*_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$interfaces),
	.interfaces=		_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xeaf7ad7a888244a0),
		.source_file=		"ConstantObject.java",
		.instance_size=		sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs) + sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$methods) / sizeof(*_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$methods),
		.methods=		_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$methods,
		.instanceof_hash_table=	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_depends) / sizeof(*_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_depends),
		.class_depends=		_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_toolkits_pointer_representations_ConstantObject= {
	    .shortString$fc1f709a9c723fa1=
		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$shortString$fc1f709a9c723fa1,
	    .toString$7ea43b33b80a3070=
		&_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070,
	},
    }
};
